==> haskell-http2-1.5.2-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-http2/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.5.2
id: http2-1.5.2-c17f65710580a09ffe9d21de5a311fa3
key: http2_8Dv1gpKLvkR59Fk0riZMp6
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: HTTP/2.0 library including frames and HPACK
description:
    HTTP/2.0 library including frames and HPACK.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.HPACK Network.HTTP2 Network.HTTP2.Priority
hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.Integer
                Network.HPACK.Table Network.HPACK.Table.Dynamic
                Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
                Network.HPACK.Table.Static Network.HPACK.Table.Token
                Network.HPACK.Types Network.HTTP2.Decode Network.HTTP2.Encode
                Network.HTTP2.Priority.PSQ Network.HTTP2.Priority.Queue
                Network.HTTP2.Types
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.5.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.5.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/http2-1.5.2
hs-libraries: HShttp2-1.5.2-8Dv1gpKLvkR59Fk0riZMp6
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    psqueues-0.2.2.0-8d3d5cbf19e7602a07362987d56a56ed
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http2-1.5.4-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-http2/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http2
version: 1.5.4
id: http2-1.5.4-328e73d4110ea2a7bdc57af8b03bb3c5
key: http2_10balJPIdy64E9R1Vluwox
license: BSD3
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: HTTP/2.0 library including frames and HPACK
description:
    HTTP/2.0 library including frames and HPACK.
category: Network
author: Kazu Yamamoto <kazu@iij.ad.jp>
exposed: True
exposed-modules:
    Network.HPACK Network.HTTP2 Network.HTTP2.Priority
hidden-modules: Network.HPACK.Buffer Network.HPACK.Builder
                Network.HPACK.Huffman Network.HPACK.Huffman.Bit
                Network.HPACK.Huffman.ByteString Network.HPACK.Huffman.Decode
                Network.HPACK.Huffman.Encode Network.HPACK.Huffman.Params
                Network.HPACK.Huffman.Table Network.HPACK.Huffman.Tree
                Network.HPACK.HeaderBlock Network.HPACK.HeaderBlock.Decode
                Network.HPACK.HeaderBlock.Encode Network.HPACK.HeaderBlock.Integer
                Network.HPACK.Table Network.HPACK.Table.Dynamic
                Network.HPACK.Table.Entry Network.HPACK.Table.RevIndex
                Network.HPACK.Table.Static Network.HPACK.Table.Token
                Network.HPACK.Types Network.HTTP2.Decode Network.HTTP2.Encode
                Network.HTTP2.Priority.PSQ Network.HTTP2.Priority.Queue
                Network.HTTP2.Types
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.5.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/http2-1.5.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/http2-1.5.4
hs-libraries: HShttp2-1.5.4-10balJPIdy64E9R1Vluwox
depends:
    array-0.5.1.0-a4b4f31b03b7779670557ea46745a386
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    psqueues-0.2.2.0-1c442d35f7d41befefb8cfb402624ddd
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
haddock-interfaces: /usr/share/doc/haskell-http2/html/http2.haddock
haddock-html: /usr/share/doc/haskell-http2/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
